Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3910)

Unified Diff: chrome/browser/ui/ash/system_tray_client.cc

Issue 2720383002: Chrome OS component updater: UpdateSeverity::LOW (Closed)
Patch Set: Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/ui/ash/system_tray_client.cc
diff --git a/chrome/browser/ui/ash/system_tray_client.cc b/chrome/browser/ui/ash/system_tray_client.cc
index 9c94470b99d627e8042f4c1f726560326b848836..47550f673e7db9729dafc468beac61d34f5b922a 100644
--- a/chrome/browser/ui/ash/system_tray_client.cc
+++ b/chrome/browser/ui/ash/system_tray_client.cc
@@ -357,9 +357,9 @@ void SystemTrayClient::HandleUpdateAvailable() {
// Get the Chrome update severity.
ash::mojom::UpdateSeverity severity = GetUpdateSeverity(detector);
// Flash updates are elevated severity unless the Chrome severity is higher.
if (flash_update_available_)
- severity = std::max(severity, ash::mojom::UpdateSeverity::ELEVATED);
+ severity = std::max(severity, ash::mojom::UpdateSeverity::LOW);
system_tray_->ShowUpdateIcon(severity, detector->is_factory_reset_required());
}
« no previous file with comments | « no previous file | no next file » | no next file with comments »
@@ -357,9 +357,9 @@ void SystemTrayClient::HandleUpdateAvailable() {
// Get the Chrome update severity.
ash::mojom::UpdateSeverity severity = GetUpdateSeverity(detector);
- // Flash updates are elevated severity unless the Chrome severity is higher.
+ // Flash updates are low severity unless the Chrome severity is higher.
if (flash_update_available_)

Powered by Google App Engine
This is Rietveld 408576698